Downloads a specified dataset table from the IRW datasource.
Usage
irw_download(
table_name,
path = NULL,
overwrite = FALSE,
source = "core",
sim = FALSE,
comp = FALSE,
nom = FALSE
)Arguments
- table_name
A character string specifying the name of the Redivis table to download.
- path
A string specifying the file path where the data should be saved. If
NULL, the dataset will be saved in the current working directory with the table's name as the file name.- overwrite
Logical. Whether to overwrite an existing file.
- source
Character. Data source:
"core"(default),"nom","sim", or"comp".- sim
Deprecated. Use
source = "sim"instead.- comp
Deprecated. Use
source = "comp"instead.- nom
Deprecated. Use
source = "nom"instead.