Shows which Redivis version each IRW dataset is being read at, and whether
that version is pinned for the session or is simply the current release.
Record these tags to make an analysis reproducible; replay them with
irw_set_version.
Shows which Redivis version each IRW dataset is being read at, and whether
that version is pinned for the session or is simply the current release.
Record these tags to make an analysis reproducible; replay them with
irw_set_version.