Skip to contents

Retrieves a summary of available tables in the IRW database, including their name, number of rows, and variable count, sorted alphabetically by table name.

Usage

irw_list_tables(source = "core", sim = FALSE, comp = FALSE, nom = FALSE)

Arguments

source

Character. Data source: "core" (default), "nom", "sim", or "comp".

sim

Deprecated. Use source = "sim" instead.

comp

Deprecated. Use source = "comp" instead.

nom

Deprecated. Use source = "nom" instead.

Value

A data frame with the following columns:

name

The name of the table, sorted alphabetically.

numRows

The number of rows in the table.

variableCount

The number of variables in the table.

Examples

if (FALSE) { # \dontrun{
irw_list_tables()               # Main IRW database
irw_list_tables(source = "sim")   # Simulation dataset
irw_list_tables(source = "comp")  # Competition dataset
} # }