Skip to contents

Fetches the metadata table from Redivis and returns it as a tibble. Automatically checks for updates and refreshes only when needed.

Usage

irw_metadata(source = "core", sim = FALSE, comp = FALSE, nom = FALSE)

Arguments

source

Character. Data source: "core" (default), "nom", "sim", or "comp".

sim

Deprecated. Use source = "sim" instead.

comp

Deprecated. Use source = "comp" instead.

nom

Deprecated. Use source = "nom" instead.

Value

A tibble containing metadata information.