Skip to contents

Retrieve the Recode Key from an Object Returned by irw_recode()

Usage

irw_recode_key(x)

Arguments

x

An object returned by irw_recode().

Value

A data frame with columns column, original, and code.