Skip to contents

Fetches the tags table from Redivis and returns it as a tibble. Link to Redivis table: https://redivis.com/datasets/bdxt-4fqe5tyf4/tables/7nkh-6m7wq01yv Automatically checks for updates and refreshes only when needed.

Usage

irw_tags(tables = NULL, source = "core")

Arguments

tables

Optional. A character vector of table name(s) to filter by.

source

Character. Data source: "core" (default) or "nom". "comp" and "sim" have no tags by design and error.

Value

A tibble containing tags information.

Examples

if (FALSE) { # \dontrun{
irw_tags()                  # core
irw_tags(source = "nom")    # nominal
} # }