Retrieve the Recode Key from an Object Returned by irw_recode()
Source:R/recode.R
irw_recode_key.RdRetrieve the Recode Key from an Object Returned by irw_recode()
Arguments
- x
An object returned by
irw_recode().
R/recode.R
irw_recode_key.RdRetrieve the Recode Key from an Object Returned by irw_recode()
An object returned by irw_recode().