Saves BibTeX entries for one or more IRW tables to a specified output file. Updates the BibTeX key to match the table name.
Usage
irw_save_bibtex(
table_names,
output_file = "refs.bib",
source = "core",
comp = FALSE,
sim = FALSE,
nom = FALSE
)Arguments
- table_names
A character vector of table names for which BibTeX entries are generated.
- output_file
A character string specifying the file path to save BibTeX entries. Default is "refs.bib".
- source
Character. Data source:
"core"(default),"nom","sim", or"comp".- comp
Deprecated. Use
source = "comp"instead.- sim
Deprecated. Use
source = "sim"instead.- nom
Deprecated. Use
source = "nom"instead. Only one of comp/sim/nom may be TRUE.